zip

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 15, 2025 License: ISC Imports: 6 Imported by: 0

README

The Goal extension package zip provides functionality for reading and writing zip files.

Documentation

Overview

Package zip provides zip archive support for Goal.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Import

func Import(ctx *goal.Context, pfx string)

Import registers in the given Context the variadic functions from this package with default names and stores them into global variables. The following functions are defined:

zip.open[s] : open zip file at given path s and return a file system value.

zip.write[s;fs] : write file system value fs to new zip file named s.

A non-empty prefix can be provided, but "zip." is already a part of the default names, so it will be added as an extra prefix.

Types

This section is empty.

Jump to