Documentation
¶
Overview ¶
Package zip provides zip archive support for Goal.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Import ¶
Import registers in the given Context the variadic functions from this package with default names and stores them into global variables. The following functions are defined:
zip.open[s] : open zip file at given path s and return a file system value.
zip.write[s;fs] : write file system value fs to new zip file named s.
A non-empty prefix can be provided, but "zip." is already a part of the default names, so it will be added as an extra prefix.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.